<#
.Synopsis
    iMacros Demo Macros Self-Test Script
	by Progress Software Corporation
#>

# Region Using
[void][reflection.assembly]::LoadWithPartialName("System.Windows.Forms")
# endregion

# Region Main code
Write-Host "Start $MyInvocation.MyCommand.Name" -ForegroundColor Yellow

$iim1 = new-object -com "imacros"

# Specify macros folder
$mydocs = [Environment]::GetFolderPath("MyDocuments")
$iMacrosPath = Join-Path -Path $mydocs -ChildPath "iMacros\Macros\Demo"

# Specify the browser, e.g. IM: " "
$Browser="-ng"

# Specify the macro(s) to be run or just run all macros in the selected folder
$macro = @()
$macro = Get-ChildItem $iMacrosPath -Filter *.iim -Name # runs all the macros in the folder
$countMacros = $macro.Length

# Start browser
$i = $iim1.iimOpen($Browser, "false")
Write-Host "Start browser, return message:" $i $iim1.iimGetErrorText() -ForegroundColor Green

# Execute macro and store the result
Write-Host "Execute test macros" -ForegroundColor Green
$ResultTable=@()
$m = 0
foreach ($element in $macro)
{
    #Create new row in the table
    $ResultRow = New-Object PSObject
    Add-Member -InputObject $ResultRow -MemberType NoteProperty -Name "No" -Value ""
    Add-Member -InputObject $ResultRow -MemberType NoteProperty -Name Time -Value ""
    Add-Member -InputObject $ResultRow -MemberType NoteProperty -Name "Macro Name" -Value ""
    Add-Member -InputObject $ResultRow -MemberType NoteProperty -Name "Return Result" -Value ""
    Add-Member -InputObject $ResultRow -MemberType NoteProperty -Name "Return Message" -Value ""

    #Retrieve results
    #Macro No.
    $ResultRow."No" = $m + 1

    # Date
    $ResultRow.Time = Get-Date -Format HH:mm:ss
    $ResultRow."Macro Name" = $macro[$m]

    # Return Result
    $ResultRow."Return Result" = $iim1.iimPlay("$iMacrosPath\"+$macro[$m], 90)

    # Return Message
    $ResultRow."Return Message" = $iim1.iimGetErrorText()

    #Save the row to the result table
    $ResultTable += $ResultRow
    $m+=1
}

#Create GridView of the results
$ResultTable | Export-Clixml -Path $PSScriptRoot\PlayAllDemo-Results.xml
$Date = (Get-Date -Format f)
Import-Clixml -Path $PSScriptRoot\PlayAllDemo-Results.xml | Out-GridView -Title "iMacros Demos Self Test Results ($Date)"
Write-Host "End Test" -ForegroundColor Yellow

#End
$i = $iim1.iimClose()
