' iMacros Combine-Macros Script
' Copyright © 1992-2021 Progress Software Corporation and/or one of its subsidiaries or affiliates.
' All rights reserved.

' This script creates a script-specific error log (instead of pop-up messages).
' The advantage of an error log instead of a pop-up is that the script
' continues running even after an error appears. An example of an error would
' be a timeout due to a temporarily slow web site.

Option Explicit

Const OPEN_FILE_FOR_APPENDING = 8

' Init the iMacros scripting interface
Dim iim1, ret
Set iim1 = CreateObject("iMacros")

Call MsgBox("This example script calls several macros. Each macro performs a specific function on the website: " &_
	"loading the website with Wsh-Start; form filling with Wsh-Lunch; and finally submitting the form with Wsh-Submit-Button." & vbNewLine & vbNewLine &_
	"The script also demonstrates how to create a script-specific error log file.", _
	vbOkOnly, WScript.ScriptName)

' Get the current folder
Dim mypath : mypath = Left(WScript.ScriptFullName, InStrRev(WScript.ScriptFullName, "\"))

' Generate a logfile name based on the script name
Dim logFileName : logFileName = Replace(WScript.ScriptName, ".vbs", "") & "-errorlog.txt"
Dim fso, logFile

' Open the log file
Set fso = CreateObject("Scripting.FileSystemObject")
Set logFile = fso.OpenTextFile(logFileName, OPEN_FILE_FOR_APPENDING, True)

logFile.WriteLine(Now() & vbNewLine & "Error Log for " & WScript.ScriptName & " demo script")

Dim browserSwitches : browserSwitches = "-ng"
Dim browserIsOpen : browserIsOpen = False

' Browser switches can be passed to the script via the command line
If WScript.Arguments.Count > 0 Then
	Dim arg, args
	For Each arg In WScript.Arguments
		args = args & arg & " "
	Next
	browserSwitches = Trim(args)
End If

' Open the browser
ret = iim1.iimOpen(CStr(browserSwitches))
If ret < 0 Then LogErrorAndQuit("OPEN")
browserIsOpen = True

ret = iim1.iimPlay(mypath & "Macros\Wsh-Start.iim")
If ret < 0 Then LogErrorAndQuit("WSH-START")

ret = iim1.iimPlay(mypath & "Macros\Wsh-Lunch.iim")
If ret < 0 Then LogErrorAndQuit("WSH-LUNCH")

ret = iim1.iimPlay(mypath & "Macros\Wsh-Submit-Button.iim")
If ret < 0 Then LogErrorAndQuit("WSH-SUBMIT-BUTTON")

CleanUp()
WScript.Quit(ret)

Sub LogError(errSource)
	logFile.WriteLine(errSource & ": Error-No: " & ret & " => Description: " & iim1.iimGetErrorText())
End Sub

Sub LogErrorAndQuit(errSource)
	LogError(errSource)
	CleanUp()
	WScript.Quit(ret)
End Sub

Sub CleanUp()
	If browserIsOpen Then
		If iim1.iimClose() < 0 Then LogError("CLOSE")
	End If
	logFile.Close()
End Sub
