' iMacros Connect-To-Chrome Script
' Copyright © 1992-2021 Progress Software Corporation and/or one of its subsidiaries or affiliates.
' All rights reserved.

Option Explicit

' Init the iMacros scripting interface
Dim iim1, ret
Set iim1 = CreateObject("iMacros")

Call MsgBox("This example script opens an instance of Chrome." & vbNewLine & vbNewLine &_
	"For this script to work you need to have iMacros for Chrome and iMacros FileAccess installed." & vbNewLine & vbNewLine &_
	"See https://wiki.imacros.net/Webextensions", _
	vbOkOnly, WScript.ScriptName)

' Browser switches can be passed to the script via the command line
Dim browserSwitches : browserSwitches = "-cr"

If WScript.Arguments.Count > 0 Then
	Dim arg, args
	For Each arg In WScript.Arguments
		args = args & arg & " "
	Next
	browserSwitches = Trim(args)
End If

' Open the browser
ret = iim1.iimOpen(CStr(browserSwitches))
If ret < 0 Then
	Call MsgBox("Could not connect to an instance of Chrome:" & vbNewLine & vbNewLine &_
		iim1.iimGetErrorText(), vbOkOnly+vbCritical, WScript.ScriptName)
	WScript.Quit(ret)
End If

' Play a macro
Dim macro
macro = macro & "URL GOTO=https://demo.imacros.net/Automate/TestForm1" & vbNewLine
macro = macro & "TAG POS=1 TYPE=INPUT:TEXT ATTR=ID:name CONTENT=Tom<SP>Tester" & vbNewLine
macro = macro & "TAG POS=1 TYPE=SELECT ATTR=ID:food CONTENT=%Pizza" & vbNewLine
macro = macro & "TAG POS=1 TYPE=SELECT ATTR=ID:drink CONTENT=%Coke" & vbNewLine
macro = macro & "TAG POS=1 TYPE=INPUT:RADIO ATTR=ID:medium" & vbNewLine
macro = macro & "TAG POS=1 TYPE=SELECT ATTR=ID:dessert CONTENT=%ice<SP>cream:%chocolate<SP>cake" & vbNewLine
macro = macro & "TAG POS=1 TYPE=INPUT:RADIO ATTR=NAME:Customer&&VALUE:Yes" & vbNewLine
macro = macro & "SET !ENCRYPTION NO" & vbNewLine
macro = macro & "TAG POS=1 TYPE=INPUT:PASSWORD ATTR=NAME:Reg_code CONTENT=tester" & vbNewLine
macro = macro & "TAG POS=1 TYPE=TEXTAREA ATTR=NAME:Remarks CONTENT=Hi,<SP><BR><SP><SP>iMacros<SP>can<SP>fill<SP>in<SP>forms" & vbNewLine
macro = macro & "TAG POS=1 TYPE=BUTTON ATTR=TXT:Click<SP>to<SP>order<SP>now" & vbNewLine

ret = iim1.iimPlayCode(macro, 60)
If ret < 0 Then Call MsgBox("Error playing macro: " & vbNewLine & iim1.iimGetErrorText(), vbOkOnly+vbExclamation, WScript.ScriptName)

iim1.iimDisplay("Script complete!")
Call MsgBox("Click OK to close the browser and exit.", vbOkOnly+vbExclamation, WScript.ScriptName)

iim1.iimClose()
WScript.Quit(ret)
