' iMacros Connect-To-Runner Script
' Copyright © 1992-2021 Progress Software Corporation and/or one of its subsidiaries or affiliates.
' All rights reserved.

Option Explicit

' Define some error constants
Const ERR_FAIL			= -1
Const ERR_NORUNNER		= -6
Const ERR_MAXINSTANCE	= -7

' Init the iMacros scripting interface
Dim iim1, ret
Set iim1 = CreateObject("iMacros")

If vbCancel = MsgBox("This script connects to iimRunner to launch the browser. " &_
	"Use this tool for example to play macros from server-side scripts running under a web server account." & vbNewLine & vbNewLine &_
	"Make sure iimrunner.exe is running prior to running this script. The default location for this file is the iMacros program folder.", _
	vbOkCancel, WScript.ScriptName) Then
	WScript.Quit()
End If

' Get the current folder
Dim mypath : mypath = Left(WScript.ScriptFullName, InStrRev(WScript.ScriptFullName, "\"))

' Browser switches can be passed to the script via the command line
Dim browserSwitches : browserSwitches = "-ng"

If WScript.Arguments.Count > 0 Then
	Dim arg, args
	For Each arg In WScript.Arguments
		args = args & arg & " "
	Next
	browserSwitches = Trim(args)
End If

' Open the browser
ret = iim1.iimOpen("-runner " & browserSwitches)

Select Case ret
	Case ERR_NORUNNER, ERR_FAIL
		DisplayErrorAndQuit("iimRunner ist not running." & vbNewLine & vbNewLine & "Please start iimrunner.exe first. The default location for this file is the iMacros program folder.")
	Case ERR_MAXINSTANCE
		DisplayErrorAndQuit("The max number of allowed browser instances has been reached. You can change this limit in the iimrunner.xml file located in the same folder as iimrunner.exe.")
	Case ret < 0
		DisplayErrorAndQuit(iim1.iimGetErrorText())
End Select

' Play a macro
ret = iim1.iimPlay(mypath & "Macros\Wsh-Start.iim")

Call MsgBox("Demo completed. Result: " & iim1.iimGetErrorText() & vbNewLine & vbNewLine &_
	"Press OK to close the browser.", _
	vbOkOnly, WScript.ScriptName)

' Close the browser
iim1.iimClose()
WScript.Quit(ret)

Sub DisplayErrorAndQuit(errMsg)
	Call MsgBox(errMsg, vbOkOnly+vbCritical, WScript.ScriptName)
	WScript.Quit(ret)
End Sub
