' iMacros Database-2-Web Script
' Copyright © 1992-2021 Progress Software Corporation and/or one of its subsidiaries or affiliates.
' All rights reserved.

' Note for x64 users: You must start the VBS script in 32bit mode (C:\Windows\SysWOW64\wscript.exe) for
' the Microsoft ODBC Driver to work. Please see the following note about VBS scripts for more details:
'
' https://wiki.imacros.net/x64

Option Explicit

' Init the iMacros scripting interface
Dim iim1, ret
Set iim1 = CreateObject("iMacros")

If vbCancel = MsgBox("This script demonstrates how to read data from an Access database and submit this information to a website. " &_
	"It reads from the database file iim-test-submit.mdb and uses the macro Wsh-Submit-2-Web." & vbNewLine & vbNewLine &_
	"Tip: This script has the same function as file-2-web-method2.vbs but reads the data from a database instead of a text file." & vbNewLine & vbNewLine &_
	"Note for 64-bit users:" & vbNewLine &_
	"You must run the script in 32-bit mode using for the Microsoft ODBC driver to work. For example:" & vbNewLine & vbNewLine &_
	"C:\Windows\SysWOW64\wscript.exe " & WScript.ScriptName, _
	vbOkCancel, WScript.ScriptName) Then
	WScript.Quit()
End If

' Get the current folder
Dim mypath : mypath = Left(WScript.ScriptFullName, InStrRev(WScript.ScriptFullName, "\"))

' Browser switches can be passed to the script via the command line
Dim browserSwitches : browserSwitches = "-ng"

If WScript.Arguments.Count > 0 Then
	Dim arg, args
	For Each arg In WScript.Arguments
		args = args & arg & " "
	Next
	browserSwitches = Trim(args)
End If

' Open the browser
ret = iim1.iimOpen(CStr(browserSwitches))
If ret < 0 Then
	DisplayError(iim1.iimGetErrorText())
	WScript.Quit(ret)
End If

' Open the Access database
Dim db, rs
Set db = CreateObject("ADODB.Connection")

Dim connstring : connstring = "DRIVER={Microsoft Access Driver (*.mdb)}; DBQ=" & mypath & "iim-test-submit.mdb"

' NOTE: To open an SQL database instead of an Access database please use:
' connstring = "driver={SQL Server};server=<SQLServerNameHere>;uid=<SQLUserIDHere>;pwd=<SQLPasswordHere>;database=databaseNameHere>"

db.Open(connstring)

' Use SQL to select query the data
Set rs = db.Execute("select * from table1")

iim1.iimDisplay("Submitting data from MS Access database")

Do Until rs.EOF
   'Set the macro variables
   Call iim1.iimSet("FNAME", rs.fields(0))
   Call iim1.iimSet("LNAME", rs.fields(1))
   Call iim1.iimSet("ADDRESS", rs.fields(2))
   Call iim1.iimSet("CITY", rs.fields(3))
   Call iim1.iimSet("ZIP", rs.fields(4))
   Call iim1.iimSet("STATE-ID", rs.fields(5))
   Call iim1.iimSet("COUNTRY-ID", rs.fields(6))
   Call iim1.iimSet("EMAIL", rs.fields(7))

   'Run the macro (this is the same macro as in the file-2-web-method2.vbs example script!)
   ret = iim1.iimPlay(mypath & "Macros\Wsh-Submit-2-Web.iim")
   If ret < 0 Then DisplayError(iim1.iimGetErrorText())

  rs.MoveNext()
Loop

' Close the browser
iim1.iimClose()

' Close the database
Set rs = Nothing
db.Close()

WScript.Quit(ret)

Sub DisplayError(errMsg)
	Call MsgBox(errMsg, vbOkOnly+vbCritical, WScript.ScriptName)
End Sub
