' iMacros Extract-2-Database Script
' Copyright © 1992-2021 Progress Software Corporation and/or one of its subsidiaries or affiliates.
' All rights reserved.

' Note for x64 users: You must start the VBS script in 32bit mode (C:\Windows\SysWOW64\wscript.exe) for
' the Microsoft ODBC Driver to work. Please see the following note about VBS scripts for more details:
'
' https://wiki.imacros.net/x64

Option Explicit

Const SUCCESS = 1

' Init the iMacros scripting interface
Dim iim1, ret
Set iim1 = CreateObject("iMacros")

If vbCancel = MsgBox("This script demonstrates how to extract data from a web site and store this information directly in a database (MS Access). " &_
	"It writes to the database file iim-test-extract.mdb and uses the macro Wsh-Extract-Jobs." & vbNewLine & vbNewLine &_
	"Tip: This script has the same function as extract-2-file.vbs but stores the data in a database instead of a text file." & vbNewLine & vbNewLine &_
	"Note for 64-bit users:" & vbNewLine &_
	"You must run the script in 32-bit mode using for the Microsoft ODBC driver to work. For example:" & vbNewLine & vbNewLine &_
	"C:\Windows\SysWOW64\wscript.exe " & WScript.ScriptName, _
	vbOkCancel, WScript.ScriptName) Then
	WScript.Quit()
End If

' Get the current folder
Dim mypath : mypath = Left(WScript.ScriptFullName, InStrRev(WScript.ScriptFullName, "\"))

' Browser switches can be passed to the script via the command line
Dim browserSwitches : browserSwitches = "-ng"

If WScript.Arguments.Count > 0 Then
	Dim arg, args
	For Each arg In WScript.Arguments
		args = args & arg & " "
	Next
	browserSwitches = Trim(args)
End If

' Open the browser
ret = iim1.iimOpen(CStr(browserSwitches))
If ret < 0 Then
	DisplayError(iim1.iimGetErrorText())
	WScript.Quit(ret)
End If

' Opeen the Access database
Dim db
Set db = CreateObject("ADODB.Connection")

db.Open("DRIVER={Microsoft Access Driver (*.mdb)}; DBQ=" & mypath & "iim-test-extract.mdb")

' Cycle through each of the job listings on the page
Dim listingNum
For listingNum = 1 To 3
	iim1.iimDisplay("Listing No: " & listingNum)

	Call iim1.iimSet("listingNum", listingNum)

	If SUCCESS = iim1.iimPlay(mypath & "Macros\Wsh-Extract-Jobs.iim") Then
		' Use SQL to insert new data
		Dim sql : sql = "insert into tableJobListings (Salary, PositionType, RefCode) values ('" &_
			iim1.iimGetExtract(1) & "', '" & iim1.iimGetExtract(2) & "', '" & iim1.iimGetExtract(3) & "')"

		' Execute the SQL statement
		db.Execute(sql)
	Else
		DisplayError(iim1.iimGetErrorText())
	End If
Next

' Close the browser
iim1.iimClose()

' Close the database
db.Close()

Call MsgBox("The data was stored in the iim-test-extract.mdb database. The script is now complete.", vbOkOnly, WScript.ScriptName)

WScript.Quit(ret)

Sub DisplayError(errMsg)
	Call MsgBox(errMsg, vbOkOnly+vbCritical, WScript.ScriptName)
End Sub
