' iMacros Extract-2-File Script
' Copyright © 1992-2021 Progress Software Corporation and/or one of its subsidiaries or affiliates.
' All rights reserved.

Option Explicit

Const SUCCESS = 1
Const OPEN_FILE_FOR_APPENDING = 8

' Init the iMacros scripting interface
Dim iim1, ret
Set iim1 = CreateObject("iMacros")

Dim outputFileName : outputFileName = Replace(WScript.ScriptName, ".vbs", "") & "-data.txt"

Call MsgBox("This script demonstrates how to extract data from a website and store this information in a text file. " &_
	"It writes the data to " & outputFileName & " in CSV format (Comma Separated Values) and uses the macro Wsh-Extract-Jobs." & vbNewLine & vbNewLine &_
	"Tip: This script has the same function as extract-2-database.vbs but stores the data in a text file instead of a database.", _
	vbOkOnly, WScript.ScriptName)

' Get the current folder
Dim mypath : mypath = Left(WScript.ScriptFullName, InStrRev(WScript.ScriptFullName, "\"))

' Browser switches can be passed to the script via the command line
Dim browserSwitches : browserSwitches = "-ng"

If WScript.Arguments.Count > 0 Then
	Dim arg, args
	For Each arg In WScript.Arguments
		args = args & arg & " "
	Next
	browserSwitches = Trim(args)
End If

' Open the browser
ret = iim1.iimOpen(CStr(browserSwitches))
If ret < 0 Then
	DisplayError(iim1.iimGetErrorText())
	WScript.Quit(ret)
End If

' Open the output file
Dim fso, outputFile
Set fso = CreateObject("Scripting.FileSystemObject")
Set outputFile = fso.OpenTextFile(outputFileName, OPEN_FILE_FOR_APPENDING, True)

' Cycle through each of the job listings on the page
Dim listingNum
For listingNum = 1 To 3
	iim1.iimDisplay("Listing No: " & listingNum)

	Call iim1.iimSet("listingNum", listingNum)

	If SUCCESS = iim1.iimPlay(mypath & "Macros\Wsh-Extract-Jobs.iim") Then
		' Write extracted data to the output file
		outputFile.WriteLine(FormatOutputLine(Split(iim1.iimGetExtract(), "[EXTRACT]"), ","))
	Else
		DisplayError(iim1.iimGetErrorText())
	End If
Next

' Close the browser
iim1.iimClose()

' Close the output file
outputFile.Close()

Call MsgBox("The data was stored in the file " & outputFileName & ". The script is now complete.", vbOkOnly, WScript.ScriptName)

WScript.Quit(ret)

Sub DisplayError(errMsg)
	Call MsgBox(errMsg, vbOkOnly+vbCritical, WScript.ScriptName)
End Sub

Function FormatOutputLine(ValuesArray, sep)
	' Concatenates each of the values in the given Values array using sep as the delimiter.
	Dim Formatted
	Set Formatted = CreateObject("Scripting.Dictionary")

	Dim regEx
	Set regEx = New RegExp
	regEx.Pattern = sep & "|\r|\n|"""
	regEx.Global = True
	regEx.IgnoreCase = True

	Dim item
	For Each item In ValuesArray
		Dim quotesRequired : quotesRequired = regEx.Test(item)

		' Escape any embedded double-quote characters with another double-quote character
		item = Replace(item, """", """""")

		If quotesRequired Then
			item = """" & item & """"
		End If

		Formatted(Formatted.Count) = item
	Next

	FormatOutputLine = Join(Formatted.Items(), sep)
End Function
