' iMacros Extract-and-Fill Script
' Copyright © 1992-2021 Progress Software Corporation and/or one of its subsidiaries or affiliates.
' All rights reserved.

Option Explicit

' Init the iMacros scripting interface
Dim iim1, ret
Set iim1 = CreateObject("iMacros")

Call MsgBox("This example shows how to use a data EXTRACTION and then fill the extracted data into a new form, " &_
	"similar to a copy-and-paste operation. It uses two macros for this purpose: " &_
	"Wsh-Extract-Rate and Wsh-Extract-And-Fill-Part2.", _
	vbOkOnly, WScript.ScriptName)

' Get the current folder
Dim mypath : mypath = Left(WScript.ScriptFullName, InStrRev(WScript.ScriptFullName, "\"))

' Browser switches can be passed to the script via the command line
Dim browserSwitches : browserSwitches = "-ng"
Dim browserIsOpen : browserIsOpen = False

If WScript.Arguments.Count > 0 Then
	Dim arg, args
	For Each arg In WScript.Arguments
		args = args & arg & " "
	Next
	browserSwitches = Trim(args)
End If

' Open the browser
ret = iim1.iimOpen(CStr(browserSwitches))
If ret < 0 Then DisplayErrorAndQuit(iim1.iimGetErrorText())
browserIsOpen = True

' Extract the data
iim1.iimDisplay("Extracting data")
ret = iim1.iimPlay(mypath & "Macros\Wsh-Extract-Rate.iim")
If ret < 0 Then DisplayErrorAndQuit(iim1.iimGetErrorText())

' Wait a couple of seconds before playing the next macro to
' give the user a chance to view the initial page.
WScript.Sleep(2000)

Dim text : text = "Hello Jim," & vbNewLine & vbNewLine & "Did you know? One US$ costs " & iim1.iimGet("USD2EURO") & " EURO or " & iim1.iimGet("USD2GBP") & " British Pounds (GBP)."

' Submit extracted data
iim1.iimDisplay("Submitting extracted data")

Call iim1.iimSet("currency", text)
ret = iim1.iimPlay(mypath & "Macros\Wsh-Extract-And-Fill-Part2.iim")
If ret < 0 Then DisplayError(iim1.iimGetErrorText())

CleanUp()
WScript.Quit(ret)

Sub DisplayError(errMsg)
	Call MsgBox(errMsg, vbOkOnly+vbCritical, WScript.ScriptName)
End Sub

Sub DisplayErrorAndQuit(errMsg)
	DisplayError(errMsg)
	CleanUp()
	WScript.Quit(ret)
End Sub

Sub CleanUp()
	If browserIsOpen Then
		If iim1.iimClose() < 0 Then DisplayError(iim1.iimGetErrorText())
	End If
End Sub
