' iMacros File-2-Web Script
' Copyright © 1992-2021 Progress Software Corporation and/or one of its subsidiaries or affiliates.
' All rights reserved.

Option Explicit

Const ERR_USERSTOPPED	= -101
Const ERR_BROWSERCLOSED	= -102
Const ERR_ENDOFFILE		= -1240

' Init the iMacros scripting interface
Dim iim1, ret
Set iim1 = CreateObject("iMacros")

Call MsgBox("This script demonstrates how to read data from the Address.csv text file in the iMacros\DataSources folder using " &_
	"a macro (Wsh-File-2-Web) to read the data directly." & vbNewLine & vbNewLine &_
	"The script is only responsible for controlling the loop over the data. This is similar to setting a repeat value in the iMacros UI and " &_
	"playing the macro manually but offers more flexibility, e.g. when the number of records is unknown." & vbNewLine & vbNewLine &_
	"Tip: This script has the same function as file-2-web-method2.vbs but uses a different method.", _
	vbOkOnly, WScript.ScriptName)

' Get the current folder
Dim mypath : mypath = Left(WScript.ScriptFullName, InStrRev(WScript.ScriptFullName, "\"))

' Browser switches can be passed to the script via the command line
Dim browserSwitches : browserSwitches = "-ng"
Dim browserIsOpen : browserIsOpen = False

If WScript.Arguments.Count > 0 Then
	Dim arg, args
	For Each arg In WScript.Arguments
		args = args & arg & " "
	Next
	browserSwitches = Trim(args)
End If

' Open the browser
ret = iim1.iimOpen(CStr(browserSwitches))
If ret < 0 Then DisplayErrorAndQuit(iim1.iimGetErrorText())
browserIsOpen = True

iim1.iimDisplay("Submitting Data")

' Note: The input file name is hard-coded in the macro but you could also
' make it a macro variable and pass the value in from the script using iimSet.

' Loop through all the lines in the input file, starting with line 2 to skip the header row.
Dim line : line = 2
Dim moreLines : moreLines = True

Do While moreLines
	' Set the current read position
	Call iim1.iimSet("line", line)

	' Play the macro
	ret = iim1.iimPlay(mypath & "Macros\Wsh-File-2-Web.iim")

	If ret = ERR_ENDOFFILE Then
		' iMacros returns error -1240 when it tries to read past the end of a file,
		' so signal the loop to end.
		moreLines = False
	ElseIf ret = ERR_USERSTOPPED Or ret = ERR_BROWSERCLOSED Then
		' The user clicked the stop button or closed the browser, so abort the script
		If ret = ERR_BROWSERCLOSED Then browserIsOpen = False
		DisplayErrorAndQuit("Playback was interrupted by the user." & vbNewLine & vbNewLine & "Click OK to exit the script.")
	ElseIf ret < 0 Then
	   ' Some other unexpected error occurred, so abort the script. Rather than abort,
	   ' you could instead e.g. log the error to a file (see combine-macros.vbs) and
	   ' attempt to keep processing the input file.
	   DisplayErrorAndQuit(iim1.iimGetErrorText())
	End If

	' Increment the line counter
	line = line + 1
Loop

iim1.iimDisplay("Done!")
Call MsgBox("All records were submitted successfully!" & vbNewLine & vbNewLine &_
	"Press OK to close the browser and exit.", _
	vbOkOnly+vbInformation, WScript.ScriptName)

CleanUp()
WScript.Quit(ret)

Sub DisplayError(errMsg)
	Call MsgBox(errMsg, vbOkOnly+vbExclamation, WScript.ScriptName)
End Sub

Sub DisplayErrorAndQuit(errMsg)
	DisplayError(errMsg)
	CleanUp()
	WScript.Quit(ret)
End Sub

Sub CleanUp()
	If browserIsOpen Then
		If iim1.iimClose() < 0 Then DisplayError(iim1.iimGetErrorText())
	End If
End Sub
